"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ValidatorField_1 = __importDefault(require("./ValidatorField"));
const ValidatorError_1 = __importDefault(require("./Errors/ValidatorError"));
class Validator {
    constructor(rules) {
        this.rules = rules;
    }
    static get rule() {
        return new ValidatorField_1.default;
    }
    static make(rules) {
        return new Validator(rules);
    }
    each(fn) {
        for (let name in this.rules) {
            fn(this.rules[name], name);
        }
        return this;
    }
    validate(data) {
        let result = {};
        this.each((rule, name) => {
            let value = (name in data) ? data[name] : undefined;
            try {
                result[name] = rule.validate(value);
            }
            catch (e) {
                throw new ValidatorError_1.default(name, value, e.message || 'Validator Unknown Error');
            }
        });
        return result;
    }
    errNo() {
        return this.each(rule => rule.errNo());
    }
    setCustomErrors(errors) {
        return this.each(rule => rule.setCustomErrors(errors));
    }
}
exports.default = Validator;
